@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2002, 2017 IBM Corporation and others.
+ * Copyright (c) 2002, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -359,14 +359,14 @@ public abstract class ViewItem {
 	}
 
 	public boolean isCompletionMessageExpanded() {
-	    return completionMessageExpanded;
-    }
+		return completionMessageExpanded;
+	}
 
 	/**
-     * Returns whether or not cheat sheet viewer containing this item is in
-     * a modal dialog.
-     *
-     * @return whether the cheat sheet viewer is in a modal dialog
+	 * Returns whether or not cheat sheet viewer containing this item is in
+	 * a modal dialog.
+	 *
+	 * @return whether the cheat sheet viewer is in a modal dialog
 	 */
 	public boolean isInDialogMode() {
 		return viewer.isInDialogMode();
@@ -403,7 +403,7 @@ public abstract class ViewItem {
 			Point point = widget.getDisplay().getCursorLocation();
 			point = new Point(point.x + 15, point.y);
 			// display the help
-            PlatformUI.getWorkbench().getHelpSystem().displayContext(context, point.x, point.y);
+			PlatformUI.getWorkbench().getHelpSystem().displayContext(context, point.x, point.y);
 		}
 	}
 
@@ -449,8 +449,8 @@ public abstract class ViewItem {
 		if (composite != null) {
 			composite.setBackground(color);
 			Control[] children = composite.getChildren();
-			for (int i = 0; i < children.length; i++) {
-				children[i].setBackground(color);
+			for (Control element : children) {
+				element.setBackground(color);
 			}
 		}
 	}
@@ -600,8 +600,8 @@ public abstract class ViewItem {
 			titleComposite.setBackground(bg);
 
 			Control[] titlechildren = titleComposite.getChildren();
-			for (int i = 0; i < titlechildren.length; i++) {
-				titlechildren[i].setBackground(bg);
+			for (Control element : titlechildren) {
+				element.setBackground(bg);
 			}
 		}
 	}
@@ -618,6 +618,6 @@ public abstract class ViewItem {
 			bodyText.copy();
 	}
 
-   abstract boolean hasCompletionMessage();
+	abstract boolean hasCompletionMessage();
 
 }
